@@ -54,8 +54,6 @@
 #include <sys/socket.h>
 
 #ifdef NEW_AXLIB
-#include <netax25/kernel_ax25.h>	// new for libax25
-#include <netax25/kernel_rose.h>	// required by axlib.h
 #include <netax25/axlib.h>
 #include <netax25/axconfig.h>
 #include <netax25/daemon.h>
@@ -343,17 +341,27 @@ void scan_collector(struct bbs *bbs)
 void exec_download_agent(struct bbs *bbs)
 {
   char cmd[1024];
+  int r;
   snprintf(cmd, 1023, "%s %s >/dev/null", ENDOFLISTCMD,
            call_call(bbs->call));
 #ifndef DAEMON
   printf("Executing: %s", cmd);
 #endif
-  system(cmd);
+  r = system(cmd);
+  if (r < 0)
+  {
+#ifndef DAEMON
+        printf("system(%s) returned %d\n", cmd, r);
+#endif
+        ;
+  }
+
 }
 
 void exec_complete_agent(struct bbs *bbs)
 {
   char cmd[1024];
+  int r;
 
   if (time(NULL) < bbs->last_complete+bbs->waittime) return; /* too early */
   bbs->last_complete = time(NULL);
@@ -362,7 +370,14 @@ void exec_complete_agent(struct bbs *bbs)
 #ifndef DAEMON
   printf("Executing: %s", cmd);
 #endif
-  system(cmd);
+  r = system(cmd);
+  if (r < 0)
+  {
+#ifndef DAEMON
+        printf("system(%s) returned %d\n", cmd, r);
+#endif
+        ;
+  }
   bbs->last = last_message(bbs); /* recheck modified list */
   if (bbs->highest > bbs->last) bbs->last = bbs->highest;
 }
@@ -610,7 +625,7 @@ int main(int argc, char **argv)
     send_init_requests();
 
   while(1){
-    int asize = sizeof(sa);
+    socklen_t asize = sizeof(sa);
     tvp=NULL;
     next_event=0;
     for(bbs=BBSBEG;bbs;bbs=bbs->next){
@@ -634,7 +649,7 @@ int main(int argc, char **argv)
         strcpy(to_call, ax25_ntoa((ax25_address *)buffer));
         strcpy(from_call, ax25_ntoa((ax25_address *)(buffer+CALL_OFS)));
         #else
-        signed char *data = buffer+1;
+        unsigned char *data = buffer+1;
         strcpy(to_call, ax25_ntoa((ax25_address *)data));
         strcpy(from_call, ax25_ntoa((ax25_address *)(data+CALL_OFS)));
         #endif
@@ -660,12 +675,12 @@ int main(int argc, char **argv)
 
         /* handle FBB unproto frame */
 	while(*p){
-          i=strcspn(p,"\r\n");
+          i=strcspn((char *)p,"\r\n");
 	  l=p;
 	  p+=i;
 	  while(*p&&strchr("\r\n",*p)) p++;
 	  l[i]='\0';
-          handle_fbb_line(from_call,l);
+          handle_fbb_line(from_call,(char *)l);
 	}    
       }
     } else check();	// nothing in readfds -> timeout
